@@ -97,7 +97,7 @@ ctx_data_add_simple_pattern (GtkSourceContextData *ctx_data,
 	result = _gtk_source_context_data_define_context (ctx_data, real_id,
 							  root_id,
 							  fixed, NULL, NULL,
-							  style,
+							  style, NULL,
 							  GTK_SOURCE_CONTEXT_EXTEND_PARENT |
 								GTK_SOURCE_CONTEXT_END_AT_LINE_END,
 							  &error);
@@ -145,6 +145,7 @@ ctx_data_add_syntax_pattern (GtkSourceContextData *ctx_data,
 							  pattern_start,
 							  pattern_end,
 							  style,
+							  NULL,
 							  flags,
 							  &error);
 
@@ -597,11 +598,11 @@ parseTag (GtkSourceLanguage    *language,
 	}
 	else
 	{
-		xmlChar *tmp = xmlStrdup (BAD_CAST dgettext (
-							language->priv->translation_domain,
-							(gchar *)name));
+		gchar *tmp1 = _gtk_source_language_translate_string (language, (gchar*) name);
+		xmlChar *tmp2 = xmlStrdup (BAD_CAST tmp1);
 		id = name;
-		name = tmp;
+		name = tmp2;
+		g_free (tmp1);
 	}
 
 	if (name == NULL)
@@ -658,7 +659,7 @@ define_root_context (GtkSourceContextData *ctx_data,
 	id = g_strdup_printf ("%s:%s", language->priv->id, language->priv->id);
 	result = _gtk_source_context_data_define_context (ctx_data, id,
 							  NULL, NULL, NULL, NULL,
-							  NULL,
+							  NULL, NULL,
 							  GTK_SOURCE_CONTEXT_EXTEND_PARENT,
 							  &error);
 
@@ -694,8 +695,11 @@ _gtk_source_language_file_parse_version1 (GtkSourceLanguage    *language,
 	{
 		doc = xmlParseMemory (g_mapped_file_get_contents (mf),
 				      g_mapped_file_get_length (mf));
-
+#if GLIB_CHECK_VERSION(2,22,0)
+		g_mapped_file_unref (mf);
+#else
 		g_mapped_file_free (mf);
+#endif
 	}
 
 	if (doc == NULL)
@@ -777,6 +781,7 @@ _gtk_source_language_file_parse_version1 (GtkSourceLanguage    *language,
 	if (esc_char != 0)
 		_gtk_source_context_data_set_escape_char (ctx_data, esc_char);
 
+	_gtk_source_context_data_finish_parse (ctx_data, NULL, NULL);
 	_gtk_source_language_define_language_styles (language);
 
 	xmlFreeDoc (doc);
